@@ -105,7 +105,7 @@ NULL # Instead of "_PACKAGE" to remove inclusion of \alias{ATAforecasting}
 #'		 \item{fixed} : "pBullet" --> Fits ATA(p,1) where p = p* is optimized for q = 1.
 #'		 \item{search} : "qBullet" --> Fits ATA(p,q) where p = p* is optimized for q = q* (q > 0). Then, fits ATA(p*,q) where q is optimized for p = p*.
 #' }
-#' @param h The number of steps to forecast ahead.
+#' @param h The forecast horizon.
 #' When the parameter is NULL; if the frequency of \code{X} is 4, the parameter is set to 8; if the frequency of \code{X} is 12, the parameter is set to 18; the parameter is set to 6 for other cases.
 #' @param train_test_split If \code{Y} is NULL, this parameter divides \code{X} into two parts: training set (in-sample) and test set (out-sample). \code{train_test_split} is number of periods for forecasting and size of test set.
 #' If the value is between 0 and 1, percentage of length is active.
@@ -114,22 +114,32 @@ NULL # Instead of "_PACKAGE" to remove inclusion of \alias{ATAforecasting}
 #' If TRUE, holdout.set_size will used for holdout data.
 #' @param holdout.adjustedP Default is TRUE. If TRUE, parP will be adjusted by length of training - validation sets and in-sample set when the holdout forecasting is active.
 #' @param holdout.set_size If \code{holdout} is TRUE, this parameter will be same as \code{h} for defining holdout set.
+#' @param holdout.onestep Default is FALSE. if TRUE, the dynamic forecast strategy uses a one-step model multiple times (\code{h} forecast horizon) where the holdout prediction for the prior time step is used as an input for making a prediction on the following time step.
 #' @param holdin Default is FALSE. If TRUE, ATA Method uses the hold-in forecasting for accuracy measure to select the best model. In hold-in forecasting, the last h-length data points are used for accuracy measure.
 #' @param transform.order If "before", Box-Cox transformation family will be applied and then seasonal decomposition techniques will be applied. If "after", seasonal decomposition techniques will be applied and then Box-Cox transformation family will be applied.
 #' @param transform.method Transformation method  --> "Box_Cox", "Sqrt", "Reciprocal", "Log", "NegLog", "Modulus", "BickelDoksum", "Manly", "Dual", "YeoJohnson", "GPower", "GLog". If the transformation process needs shift parameter,
 #' \code{ATA.Transform} will calculate required shift parameter automatically.
 #' @param transform.attr Attributes set for Box-Cox transformation. If NULL, bcMethod = "loglik", bcLower = 0, bcUpper = 1, bcBiasAdj = FALSE. If you want to change, please use \code{ATA.BoxCoxAttr} function and its output.
-#' @param lambda Box-Cox power transformation family parameter. If NULL, data transformed before model is estimated.
-#' @param shift Box-Cox power transformation family shifting parameter. If NULL, data transformed before model is estimated.
-#' @param initial.level If NULL, FALSE is default. If FALSE, ATA Method calculates the pth observation in \code{X} for level.
-#' If TRUE, ATA Method calculates average of first p value in \code{X}for level.
-#' @param initial.trend If NULL, FALSE is default. If FALSE, ATA Method calculates the qth observation in \code{X(T)-X(T-1)} for trend.
-#' If TRUE, ATA Method calculates average of first q value in \code{X(T)-X(T-1)} for trend.
+#' @param lambda Box-Cox power transformation family parameter. Default is NULL. When "transform.method" is selected and lambda is set as NULL, required "lambda" parameter will be calculated automatically based on "transform.attr".
+#' @param shift Box-Cox power transformation family shifting parameter. Default is 0. When "transform.method" is selected, required shifting parameter will be calculated automatically according to dataset.
+#' @param initial.level "none" is default,
+#' \itemize{
+#'		 \item{none}	: ATA Method calculates the pth observation in \code{X} for level.
+#'		 \item{mean} 	: ATA Method calculates average of first p value in \code{X}for level.
+#'		 \item{median}: ATA Method calculates median of first p value in \code{X}for level.
+#' }
+#' @param initial.trend "none" is default,
+#' \itemize{
+#'		 \item{none}	: ATA Method calculates the qth observation in \code{X} for trend.
+#'		 \item{mean} 	: ATA Method calculates average of first q value in \code{X(T)-X(T-1)} for trend.
+#'		 \item{median}: ATA Method calculates median of first q value in \code{X(T)-X(T-1)} for trend.
+#' }
 #' @param ci.level Confidence Interval levels for forecasting.
 #' @param start.phi Lower boundary for searching \code{parPHI}.If NULL, 0 is default.
 #' @param end.phi Upper boundary for searching \code{parPHI}. If NULL, 1 is is default.
 #' @param size.phi Increment step for searching \code{parPHI}. If NULL, the step size will be determined as the value that allows the bounds for the optimised value of \code{parPHI} to be divided into 20 equal parts.
 #' @param negative.forecast Negative values are allowed for forecasting. Default value is TRUE. If FALSE, all negative values for forecasting are set to 0.
+#' @param onestep Default is FALSE. if TRUE, the dynamic forecast strategy uses a one-step model multiple times (\code{h} forecast horizon) where the prediction for the prior time step is used as an input for making a prediction on the following time step.
 #' @param print.out Default is TRUE. If FALSE, summary of ATA Method is not shown.
 #' @param plot.out Default is TRUE. If FALSE, graphics of ATA Method are not shown.
 #'
@@ -229,19 +239,21 @@ ATA <- function(X, Y = NULL,
                 holdout = FALSE,
                 holdout.adjustedP = TRUE,
                 holdout.set_size = NULL,
+                holdout.onestep = FALSE,
                 holdin = FALSE,
                 transform.order = "before",
                 transform.method = NULL,
                 transform.attr = NULL,
                 lambda = NULL,
                 shift = 0,
-                initial.level = NULL,
-                initial.trend = NULL,
+                initial.level = "none",
+                initial.trend = "none",
                 ci.level = 95,
                 start.phi = NULL,
                 end.phi = NULL,
                 size.phi = NULL,
                 negative.forecast = TRUE,
+                onestep = FALSE,
                 print.out = TRUE,
                 plot.out = TRUE)
 {
@@ -352,10 +364,10 @@ ATA <- function(X, Y = NULL,
   }else {
   }
   if (is.null(initial.level)){
-    initial.level = FALSE
+    initial.level = "none"
   }
   if (is.null(initial.trend)){
-    initial.trend = FALSE
+    initial.level = "none"
   }
   if (is.null(seasonal.test.attr)) {
     seas_attr_set <- ATA.SeasAttr()
@@ -441,13 +453,13 @@ ATA <- function(X, Y = NULL,
     }
   }
   if (!is.null(initial.level)){
-    if (initial.level != FALSE & initial.level != TRUE) {
-      stop("Initial value for Level must be boolean and it must get one value: TRUE or FALSE. ATAforecasting was terminated!")
+    if (initial.level != "none" & initial.level != "mean" & initial.level != "median") {
+      stop("Initial value for Level must get one value: 'none' or 'mean' or 'median'. ATAforecasting was terminated!")
     }
   }
   if (!is.null(initial.trend)){
-    if (initial.trend != FALSE & initial.trend != TRUE) {
-      stop("Initial value for Trend must be boolean and it must get one value: TRUE or FALSE. ATAforecasting was terminated!")
+    if (initial.trend != "none" & initial.trend != "mean" & initial.trend != "median") {
+      stop("Initial value for Trend must get one value: 'none' or 'mean' or 'median'. ATAforecasting was terminated!")
     }
   }
   if (!is.null(transform.order)){
@@ -456,9 +468,9 @@ ATA <- function(X, Y = NULL,
     }
   }
   if (!is.null(transform.method)){
-    if ((transform.method != "Box_Cox" & transform.method != "Box_Cox_Shift" & transform.method != "Modulus" & transform.method != "BickelDoksum" & transform.method != "Dual"  & transform.method != "Manly"  & transform.method != "Sqrt" & transform.method != "SqrtShift" &
-         transform.method != "YeoJohnson" & transform.method != "GPower" & transform.method != "GLog" & transform.method != "Log" & transform.method != "Reciprocal" & transform.method !="ReciprocalShift" & transform.method != "NegLog" &
-		     transform.method != "LogShift") | !is.character(transform.method) | length(transform.method) > 1){
+    if ((transform.method != "Box_Cox" & transform.method != "Modulus" & transform.method != "BickelDoksum" & transform.method != "Dual"  & transform.method != "Manly"  & transform.method != "Sqrt" &
+         transform.method != "YeoJohnson" & transform.method != "GPower" & transform.method != "GLog" & transform.method != "Log" & transform.method != "Reciprocal" &
+		     transform.method != "NegLog") | !is.character(transform.method) | length(transform.method) > 1){
       stop("Transform Method value must be string. Please select a valid Box-Cox transformation technique. ATAforecasting was terminated!")
     }
   }
@@ -468,6 +480,15 @@ ATA <- function(X, Y = NULL,
   if (!inherits(boxcox_attr_set, "ataoptim")){
     stop("Attributes set for Box-Cox transformation are not suitable set. ATAforecasting was terminated!")
   }
+  if (is.null(shift)){
+    shift <- 0
+    warning("'shift' is set to 0 to calculate automatically.")
+  }else{
+    if (shift<0){
+      shift <- 0
+      warning("'shift' is set to 0 to calculate automatically.")
+    }
+  }
 
   WD <- getwd()
   start.time <- Sys.time()
@@ -515,8 +536,8 @@ ATA <- function(X, Y = NULL,
                 "seasonal" = ifelse(is.null(seasonal.type), "opt", seasonal.type),
                 "period" = s.frequency,
                 "decomp_model" = seasonal.model,
-                "initial_level" = ifelse(initial.level==FALSE, NA, TRUE),
-                "initial_trend" = ifelse(initial.trend==FALSE, NA, TRUE))
+                "initial_level" = ifelse(initial.level=="none", NA, TRUE),
+                "initial_trend" = ifelse(initial.trend=="none", NA, TRUE))
   par_specs <- c(stats::na.omit(unlist(par.specs)))
   np <- length(par_specs)
   if (np >= length(train_set) - 1) {
@@ -530,11 +551,13 @@ ATA <- function(X, Y = NULL,
     if (length(seasonal.type)==1 & length(seasonal.model)==1){
       my_list <- SubATA_Single_Before(train_set, parP, parQ, model.type, seasonal.test, seasonal.model, seasonal.type, s.frequency, h, accuracy.type,
                                 level.fixed, trend.fixed, trend.search, start.phi, end.phi, size.phi, initial.level, initial.trend, transform.method,
-                                lambda, shift, main_set, test_set, seas_attr_set, freqYh, ci.level, negative.forecast, boxcox_attr_set, holdout, holdout.set_size, holdout.adjustedP, holdin, nmse)
+                                lambda, shift, main_set, test_set, seas_attr_set, freqYh, ci.level, negative.forecast, boxcox_attr_set, holdout,
+                                holdout.set_size, holdout.adjustedP, holdin, nmse, onestep, holdout.onestep)
     }else {
       my_list <- SubATA_Multi_Before(train_set, parP, parQ, model.type, seasonal.test, seasonal.model, seasonal.type, s.frequency, h, accuracy.type,
                                   level.fixed, trend.fixed, trend.search, start.phi, end.phi, size.phi, initial.level, initial.trend, transform.method,
-                                  lambda, shift, main_set, test_set, seas_attr_set, freqYh, ci.level, negative.forecast, boxcox_attr_set, holdout, holdout.set_size, holdout.adjustedP, holdin, nmse)
+                                  lambda, shift, main_set, test_set, seas_attr_set, freqYh, ci.level, negative.forecast, boxcox_attr_set, holdout,
+                                  holdout.set_size, holdout.adjustedP, holdin, nmse, onestep, holdout.onestep)
     }
   }else {
     if (!is.null(transform.method)){
@@ -544,27 +567,31 @@ ATA <- function(X, Y = NULL,
     if (length(seasonal.type)==1 & length(seasonal.model)==1){
       my_list <- SubATA_Single_After(train_set, parP, parQ, model.type, seasonal.test, seasonal.model, seasonal.type, s.frequency, h, accuracy.type,
                                  level.fixed, trend.fixed, trend.search, start.phi, end.phi, size.phi, initial.level, initial.trend, transform.method,
-                                 lambda, shift, main_set, test_set, seas_attr_set, freqYh, ci.level, negative.forecast, boxcox_attr_set, holdout, holdout.set_size, holdout.adjustedP, holdin, nmse)
+                                 lambda, shift, main_set, test_set, seas_attr_set, freqYh, ci.level, negative.forecast, boxcox_attr_set, holdout,
+                                 holdout.set_size, holdout.adjustedP, holdin, nmse, onestep, holdout.onestep)
     }else {
       my_list <- SubATA_Multi_After(train_set, parP, parQ, model.type, seasonal.test, seasonal.model, seasonal.type, s.frequency, h, accuracy.type,
                                    level.fixed, trend.fixed, trend.search, start.phi, end.phi, size.phi, initial.level, initial.trend, transform.method,
-                                   lambda, shift, main_set, test_set, seas_attr_set, freqYh, ci.level, negative.forecast, boxcox_attr_set, holdout, holdout.set_size, holdout.adjustedP, holdin, nmse)
+                                   lambda, shift, main_set, test_set, seas_attr_set, freqYh, ci.level, negative.forecast, boxcox_attr_set, holdout,
+                                   holdout.set_size, holdout.adjustedP, holdin, nmse, onestep, holdout.onestep)
     }
   }
 
   my_list$transform.order <- transform.order
   my_list$trend.opt <- trend.opt
+  my_list$holdout.onestep <- TRUE
   executionTime <- proc.time() - ptm
   end.time <- Sys.time()
   my_list$execution.time <- executionTime
   my_list$calculation.time <- round(as.double(difftime(end.time, start.time,units="sec")),4)
-  attr(my_list, "class") <- "ata"
   if (plot.out==TRUE) {
     ATA.Plot(my_list)
   }
   if (print.out==TRUE) {
     ATA.Print(my_list)
   }
+  my_list<-my_list[order(names(my_list))]
+  attr(my_list, "class") <- "ata"
   gc()
   return(my_list)
 }
