@@ -1,3 +1,6 @@
+#' @keywords internal
+"_PACKAGE"
+
 #' @import Rcpp
 #'
 #' @importFrom graphics axis legend layout lines mtext par plot polygon
@@ -6,7 +9,7 @@
 #' @importFrom seasonal seas series udg
 #' @importFrom stats acf as.ts cycle decompose frequency median na.omit qnorm qt sd ts tsp tsp<- spec.ar stl var
 #' @importFrom stlplus stlplus
-#' @importFrom stR AutoSTR components
+#' @importFrom stR AutoSTR
 #' @importFrom timeSeries colKurtosis colSkewness
 #' @importFrom TSA periodogram
 #' @importFrom tseries adf.test kpss.test pp.test
